Class: Savon::Request
- Inherits:
-
Object
- Object
- Savon::Request
- Defined in:
- lib/ext/savon/request.rb
Instance Method Summary collapse
-
#http ⇒ Object
Returns the Net::HTTP object.
-
#soap_headers ⇒ Object
FIXME Must add a double quote (") to the soap action for Sunspot to recognize it properly.
Instance Method Details
#http ⇒ Object
Returns the Net::HTTP object.
Changed the verify mode to "VERIFY_NONE" to get rid of "warning: peer certificate won't be verified in this SSL session" before each request.
14 15 16 17 18 19 20 21 |
# File 'lib/ext/savon/request.rb', line 14 def http unless @http @http = Net::HTTP::Proxy(@proxy.host, @proxy.port).new @endpoint.host, @endpoint.port @http.read_timeout = 300 @http.ssl_client_auth(:verify_mode => OpenSSL::SSL::VERIFY_NONE) end @http end |
#soap_headers ⇒ Object
FIXME Must add a double quote (") to the soap action for Sunspot to recognize it properly
6 7 8 |
# File 'lib/ext/savon/request.rb', line 6 def soap_headers { "Content-Type" => ContentType[@soap.version], "SOAPAction" => "\"#{@soap.action}\"" } end |